/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 France Telecom R&D
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: AsyncHandler.java 20489 2010-10-20 15:51:35Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.cxf.transport.mdb.api;

/**
 * Interface used by clients of asynchronous web services.
 * @author Florent Benoit
 */
public interface AsyncHandler {

    /**
     * Handler needs to persist the given correlation ID given by the client emitter.
     * @param contextInfo data about the invocation like the correlation ID, endpoint name, etc.
     */
    void saveContext(ContextInfo contextInfo);

    /**
     * @param contextInfo data about the invocation like the correlation ID, endpoint name, etc.
     * @return true if the given ID is matching one of our IDs
     */
    boolean doYouKnowThisContext(ContextInfo contextInfo);

    /**
     * Response to handle if doYouKnowThisID() call was successful.
     * @param response the response object
     * @param contextInfo data about the invocation like the correlation ID, endpoint name, etc.
     */
    void doHandlerResponse(Object response, ContextInfo contextInfo);
    
    /**
     * Handle a given fault
     * @param exception the exception object
     * @param contextInfo data about the invocation like the correlation ID, endpoint name, etc.
     */
    void doHandlerFault(Throwable exception, ContextInfo contextInfo);
}
